requesttree

package
v0.0.0-...-c31ea8c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2016 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CurrentEndpointFor

func CurrentEndpointFor(ctx context.Context) string

CurrentEndpointFor returns the current endpoint that this context is executing within

func CurrentServiceFor

func CurrentServiceFor(ctx context.Context) string

CurrentServiceFor returns the current service that this context is executing within

func Middleware

func Middleware() requestTreeMiddleware

func OriginEndpointFor

func OriginEndpointFor(ctx context.Context) string

OriginEndpointFor returns the originating endpoint for this context

func OriginServiceFor

func OriginServiceFor(ctx context.Context) string

OriginServiceFor returns the originating service for this context

func ParentRequestIdFor

func ParentRequestIdFor(ctx context.Context) string

ParentRequestIdFor returns the parent request ID for the provided context (if any).

Types

This section is empty.

Jump to