transport

package
v0.0.0-...-c31ea8c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2016 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetDefaultTransport

func SetDefaultTransport(t Transport)

SetDefaultTransport replaces the global default transport. When replacing, it does not close the prior transport.

Types

type Transport

type Transport ttrans.Transport

func DefaultTransport

func DefaultTransport() Transport

DefaultTransport returns the global default transport, over which servers and clients should run by default

Jump to