Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CurrentEndpointFor ¶
CurrentEndpointFor returns the current endpoint that this context is executing within
func CurrentServiceFor ¶
CurrentServiceFor returns the current service that this context is executing within
func Middleware ¶
func Middleware() requestTreeMiddleware
func OriginEndpointFor ¶
OriginEndpointFor returns the originating endpoint for this context
func OriginServiceFor ¶
OriginServiceFor returns the originating service for this context
func ParentRequestIdFor ¶
ParentRequestIdFor returns the parent request ID for the provided context (if any).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.